==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiCore/QXmlStreamNamespaceDeclaration_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qxmlstream.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QXmlStreamNamespaceDeclaration(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QXmlStreamNamespaceDeclaration")
    QXmlStreamNamespaceDeclaration *_ptr = reinterpret_cast<QXmlStreamNamespaceDeclaration *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QXmlStreamNamespaceDeclaration()
void __qt_construct_QXmlStreamNamespaceDeclaration_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlStreamNamespaceDeclaration()")
    Q_UNUSED(__java_arguments)
    QXmlStreamNamespaceDeclaration *__qt_this = new(__qtjambi_ptr) QXmlStreamNamespaceDeclaration();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QXmlStreamNamespaceDeclaration(QString,QString)
void __qt_construct_QXmlStreamNamespaceDeclaration_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlStreamNamespaceDeclaration(QString,QString)")
    jstring prefix0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_prefix0 = qtjambi_cast<QString >(__jni_env, prefix0);
    jstring namespaceUri1 = static_cast<jstring>(__java_arguments[1].l);
    QString  __qt_namespaceUri1 = qtjambi_cast<QString >(__jni_env, namespaceUri1);
    QXmlStreamNamespaceDeclaration *__qt_this = new(__qtjambi_ptr) QXmlStreamNamespaceDeclaration(__qt_prefix0, __qt_namespaceUri1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QXmlStreamNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
void __qt_construct_QXmlStreamNamespaceDeclaration_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlStreamNamespaceDeclaration(QXmlStreamNamespaceDeclaration)")
    jobject arg__1 = __java_arguments[0].l;
    const QXmlStreamNamespaceDeclaration& __qt_arg__1 = qtjambi_cast<const QXmlStreamNamespaceDeclaration& >(__jni_env, arg__1);
    QXmlStreamNamespaceDeclaration *__qt_this = new(__qtjambi_ptr) QXmlStreamNamespaceDeclaration(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QXmlStreamNamespaceDeclaration
void __qt_destruct_QXmlStreamNamespaceDeclaration(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QXmlStreamNamespaceDeclaration")
    reinterpret_cast<QXmlStreamNamespaceDeclaration*>(ptr)->~QXmlStreamNamespaceDeclaration();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_initialize_1native__Lio_qt_core_QXmlStreamNamespaceDeclaration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlStreamNamespaceDeclaration_0, sizeof(QXmlStreamNamespaceDeclaration), typeid(QXmlStreamNamespaceDeclaration), false, &deleter_QXmlStreamNamespaceDeclaration, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration(QString,QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_initialize_1native__Lio_qt_core_QXmlStreamNamespaceDeclaration_2Ljava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring prefix0,
 jstring namespaceUri1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration(QString,QString)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = prefix0;
        arguments[1].l = namespaceUri1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlStreamNamespaceDeclaration_1, sizeof(QXmlStreamNamespaceDeclaration), typeid(QXmlStreamNamespaceDeclaration), false, &deleter_QXmlStreamNamespaceDeclaration, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_initialize_1native__Lio_qt_core_QXmlStreamNamespaceDeclaration_2Lio_qt_core_QXmlStreamNamespaceDeclaration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration(QXmlStreamNamespaceDeclaration)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlStreamNamespaceDeclaration_2, sizeof(QXmlStreamNamespaceDeclaration), typeid(QXmlStreamNamespaceDeclaration), false, &deleter_QXmlStreamNamespaceDeclaration, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlStreamNamespaceDeclaration::namespaceUri()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_namespaceUri_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamNamespaceDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNamespaceDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNamespaceDeclaration::namespaceUri()const", __qt_this)
        QStringRef __qt_return_value = __qt_this->namespaceUri();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamNamespaceDeclaration::operator=(QXmlStreamNamespaceDeclaration)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_assign_1native_1cref_1QXmlStreamNamespaceDeclaration__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QXmlStreamNamespaceDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNamespaceDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNamespaceDeclaration::operator=(QXmlStreamNamespaceDeclaration)", __qt_this)
        const QXmlStreamNamespaceDeclaration& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QXmlStreamNamespaceDeclaration>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlStreamNamespaceDeclaration::operator==(QXmlStreamNamespaceDeclaration)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_operator_1equal_1native_1cref_1QXmlStreamNamespaceDeclaration_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamNamespaceDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNamespaceDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNamespaceDeclaration::operator==(QXmlStreamNamespaceDeclaration)const", __qt_this)
        const QXmlStreamNamespaceDeclaration& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QXmlStreamNamespaceDeclaration>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamNamespaceDeclaration::prefix()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_prefix_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamNamespaceDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNamespaceDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNamespaceDeclaration::prefix()const", __qt_this)
        QStringRef __qt_return_value = __qt_this->prefix();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QXmlStreamNamespaceDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNamespaceDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QXmlStreamNamespaceDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNamespaceDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QXmlStreamNamespaceDeclaration(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QXmlStreamNamespaceDeclaration>("QXmlStreamNamespaceDeclaration", "io/qt/core/QXmlStreamNamespaceDeclaration");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QXmlStreamNamespaceDeclaration, {
        ConstructorInfo(&__qt_construct_QXmlStreamNamespaceDeclaration_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QXmlStreamNamespaceDeclaration_1, "Ljava/lang/String;Ljava/lang/String;")
       ,ConstructorInfo(&__qt_construct_QXmlStreamNamespaceDeclaration_2, "Lio/qt/core/QXmlStreamNamespaceDeclaration;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QXmlStreamNamespaceDeclaration);
    registerMetaType<QXmlStreamNamespaceDeclaration>("QXmlStreamNamespaceDeclaration");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiCore/QXmlStreamNamespaceDeclaration_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qxmlstream.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QXmlStreamNamespaceDeclaration(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QXmlStreamNamespaceDeclaration")
    QXmlStreamNamespaceDeclaration *_ptr = reinterpret_cast<QXmlStreamNamespaceDeclaration *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QXmlStreamNamespaceDeclaration()
void __qt_construct_QXmlStreamNamespaceDeclaration(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlStreamNamespaceDeclaration()")
    Q_UNUSED(__java_arguments)
    QXmlStreamNamespaceDeclaration *__qt_this = new(__qtjambi_ptr) QXmlStreamNamespaceDeclaration();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_initialize_1native__Lio_qt_core_QXmlStreamNamespaceDeclaration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlStreamNamespaceDeclaration, sizeof(QXmlStreamNamespaceDeclaration), typeid(QXmlStreamNamespaceDeclaration), 0, false, &deleter_QXmlStreamNamespaceDeclaration, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QXmlStreamNamespaceDeclaration(QString,QString)
void __qt_construct_QXmlStreamNamespaceDeclaration_cref_QString_cref_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlStreamNamespaceDeclaration(QString,QString)")
    jstring prefix0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_prefix0 = qtjambi_cast<QString>(__jni_env, prefix0);
    jstring namespaceUri1 = static_cast<jstring>(__java_arguments[1].l);
    QString  __qt_namespaceUri1 = qtjambi_cast<QString>(__jni_env, namespaceUri1);
    QXmlStreamNamespaceDeclaration *__qt_this = new(__qtjambi_ptr) QXmlStreamNamespaceDeclaration(__qt_prefix0, __qt_namespaceUri1);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration(QString,QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_initialize_1native__Lio_qt_core_QXmlStreamNamespaceDeclaration_2Ljava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring prefix0,
 jstring namespaceUri1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration(QString,QString)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = prefix0;
        arguments[1].l = namespaceUri1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlStreamNamespaceDeclaration_cref_QString_cref_QString, sizeof(QXmlStreamNamespaceDeclaration), typeid(QXmlStreamNamespaceDeclaration), 0, false, &deleter_QXmlStreamNamespaceDeclaration, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QXmlStreamNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
void __qt_construct_QXmlStreamNamespaceDeclaration_cref_QXmlStreamNamespaceDeclaration(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlStreamNamespaceDeclaration(QXmlStreamNamespaceDeclaration)")
    jobject other0 = __java_arguments[0].l;
    const QXmlStreamNamespaceDeclaration& __qt_other0 = qtjambi_cast<const QXmlStreamNamespaceDeclaration&>(__jni_env, other0);
    QXmlStreamNamespaceDeclaration *__qt_this = new(__qtjambi_ptr) QXmlStreamNamespaceDeclaration(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_initialize_1native__Lio_qt_core_QXmlStreamNamespaceDeclaration_2Lio_qt_core_QXmlStreamNamespaceDeclaration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration(QXmlStreamNamespaceDeclaration)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlStreamNamespaceDeclaration_cref_QXmlStreamNamespaceDeclaration, sizeof(QXmlStreamNamespaceDeclaration), typeid(QXmlStreamNamespaceDeclaration), 0, false, &deleter_QXmlStreamNamespaceDeclaration, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QXmlStreamNamespaceDeclaration
void __qt_destruct_QXmlStreamNamespaceDeclaration(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QXmlStreamNamespaceDeclaration")
    reinterpret_cast<QXmlStreamNamespaceDeclaration*>(ptr)->~QXmlStreamNamespaceDeclaration();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QXmlStreamNamespaceDeclaration::namespaceUri()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_namespaceUri_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamNamespaceDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNamespaceDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNamespaceDeclaration::namespaceUri()const", __this_nativeId)
        QStringView __qt_return_value = __qt_this->namespaceUri();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamNamespaceDeclaration::operator==(QXmlStreamNamespaceDeclaration)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_equals_1native_1cref_1QXmlStreamNamespaceDeclaration_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamNamespaceDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNamespaceDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNamespaceDeclaration::operator==(QXmlStreamNamespaceDeclaration)const", __this_nativeId)
        const QXmlStreamNamespaceDeclaration& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QXmlStreamNamespaceDeclaration>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlStreamNamespaceDeclaration::prefix()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_prefix_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlStreamNamespaceDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNamespaceDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlStreamNamespaceDeclaration::prefix()const", __this_nativeId)
        QStringView __qt_return_value = __qt_this->prefix();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QXmlStreamNamespaceDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNamespaceDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QXmlStreamNamespaceDeclaration_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QXmlStreamNamespaceDeclaration *__qt_this = QtJambiAPI::objectFromNativeId<QXmlStreamNamespaceDeclaration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QXmlStreamNamespaceDeclaration(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QXmlStreamNamespaceDeclaration>("QXmlStreamNamespaceDeclaration", "io/qt/core/QXmlStreamNamespaceDeclaration");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QXmlStreamNamespaceDeclaration, {
        ConstructorInfo(&__qt_construct_QXmlStreamNamespaceDeclaration, nullptr)
       ,ConstructorInfo(&__qt_construct_QXmlStreamNamespaceDeclaration_cref_QString_cref_QString, "Ljava/lang/String;Ljava/lang/String;")
       ,ConstructorInfo(&__qt_construct_QXmlStreamNamespaceDeclaration_cref_QXmlStreamNamespaceDeclaration, "Lio/qt/core/QXmlStreamNamespaceDeclaration;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QXmlStreamNamespaceDeclaration);
    registerMetaType<QXmlStreamNamespaceDeclaration>("QXmlStreamNamespaceDeclaration");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
